@@ -25,8 +25,7 @@ test_that("QA and plot.QA work",{
   expect_is(qa2, "QA")
   expect_silent(plot(qa1, qa2))
   expect_silent(plot(qa3))
-  expect_error(plot.QA(d1))
-  expect_error(plot.QA(qa1, outDir = 2))
-  expect_silent(plot.QA(qa1, qa2))
-  expect_silent(plot.QA(qa1, outDir = tempdir()))
-})
\ No newline at end of file
+  expect_error(plot(qa1, outDir = 2))
+  expect_silent(plot(qa1, qa2))
+  expect_silent(plot(qa1, outDir = tempdir()))
+})
